==> vue-mce-1.4.0.tgz: package/src/component/index.js <==
export default {
  props: {
    config: {
      type: Object,
      default: () => ({}),
    },
    value: {
      type: String,
      default: '',
    },
    initialValue: {
      type: String,
      default: '',
    },
    name: {
      type: String,
      default: '',
    },
  },
  
  data: () => ({
    editorInstance: null,
    content: '',
  }),
  
  methods: {
    handleError (err) {
      this.$emit('error', err);
    },

    handleSuccess (editor) {
      this.editorInstance = editor;
      this.$emit('init', editor);

      const content = this.initialValue || this.value;

      editor.setContent(content);
      editor.on('input change undo redo setcontent', this.handleInput);
      editor.on('change setcontent', this.handleChange);
    },

    setContent (content) {
      try {
        this.editorInstance.setContent(content);
      } catch (err) {
        this.handleError(err);
      }
    },

    getContent () {
      return this.editorInstance.getContent();
    },
    
    handleInput () {
      const content = this.editorInstance.getContent();
      this.content = content;
      this.$emit('input', content);
    },
    
    handleChange () {
      this.$emit('change', this.content);
    },
  },

  watch: {
    initialValue (newValue) {
      this.setContent(newValue);
    },
  },

  mounted () {
    if (!window.tinymce) {
      return this.handleError(new Error("TinyMce wasn't found"));
    }

    const config = this.config;
    const target = this.$refs.textarea;

    config.target = target;
    config.init_instance_callback = this.handleSuccess;

    window.tinymce.init(config).catch(this.handleError);
  },
  
  beforeDestroy () {
    this.$emit('destroy', this.editorInstance);
    window.tinymce.remove(this.$refs.textarea);
  },
};

==> vue-mce-1.4.1.tgz: package/src/component/index.js <==
export default {
  props: {
    config: {
      type: Object,
      default: () => ({}),
    },
    value: {
      type: String,
      default: '',
    },
    initialValue: {
      type: String,
      default: '',
    },
    name: {
      type: String,
      default: '',
    },
  },
  
  data: () => ({
    editorInstance: null,
    content: '',
  }),
  
  methods: {
    handleError (err) {
      this.$emit('error', err);
    },

    handleSuccess (editor) {
      this.editorInstance = editor;
      this.$emit('init', editor);

      const content = this.initialValue || this.value;

      editor.setContent(content);
      editor.on('input change undo redo setcontent', this.handleInput);
      editor.on('change setcontent', this.handleChange);
    },

    setContent (content) {
      try {
        this.editorInstance.setContent(content);
      } catch (err) {
        this.handleError(err);
      }
    },

    getContent () {
      const { editorInstance } = this;

      if (editorInstance) {
        return editorInstance.getContent();
      }

      this.handleError(new Error('vue-mce is not initialized yet'));
      return null;
    },
    
    handleInput () {
      const content = this.editorInstance.getContent();
      this.content = content;
      this.$emit('input', content);
    },
    
    handleChange () {
      this.$emit('change', this.content);
    },
  },

  watch: {
    initialValue (newValue) {
      this.setContent(newValue);
    },
  },

  mounted () {
    if (!window.tinymce) {
      return this.handleError(new Error("TinyMce wasn't found"));
    }

    const config = this.config;
    const target = this.$refs.textarea;

    config.target = target;
    config.init_instance_callback = this.handleSuccess;

    window.tinymce.init(config).catch(this.handleError);
  },
  
  beforeDestroy () {
    this.$emit('destroy', this.editorInstance);
    window.tinymce.remove(this.$refs.textarea);
  },
};
